# Changelog

## [v0.1.1](https://github.com/kai2nenobu/aws-clipper/compare/v0.1.0...v0.1.1) - 2023-10-16
- build(deps-dev): bump flake8 from 6.0.0 to 6.1.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/45
- build(deps-dev): bump tox from 4.6.4 to 4.8.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/47
- build(deps-dev): bump mypy from 1.4.1 to 1.5.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/46
- build(deps-dev): bump types-pyyaml from 6.0.12.10 to 6.0.12.11 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/43
- build(deps-dev): bump tox from 4.8.0 to 4.9.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/50
- build(deps-dev): bump mypy from 1.5.0 to 1.5.1 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/49
- build(deps-dev): bump tox from 4.9.0 to 4.10.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/51
- build(deps-dev): bump pre-commit from 3.3.3 to 3.5.0 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/61
- build(deps-dev): bump tox from 4.10.0 to 4.11.3 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/58
- build(deps-dev): bump black from 23.7.0 to 23.9.1 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/57
- build(deps-dev): bump pytest from 7.4.0 to 7.4.2 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/59
- build(deps-dev): bump types-pyyaml from 6.0.12.11 to 6.0.12.12 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/60
- build(deps): bump tibdex/github-app-token from 1 to 2 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/56
- build(deps): bump actions/checkout from 3 to 4 by @dependabot in https://github.com/kai2nenobu/aws-clipper/pull/55

## [v0.1.0](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.8...v0.1.0) - 2023-07-20
- Drop python 3.7 by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/41

## [v0.0.8](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.7...v0.0.8) - 2023-05-04
- Add MIT license file by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/31
- Test multiple versions by tox by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/33

## [v0.0.7](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.6...v0.0.7) - 2023-04-26
- Enrich project info by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/28

## [v0.0.6](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.5...v0.0.6) - 2023-04-26
- Use src layout for a project structure by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/25
- Build single executables by PyInstaller by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/24

## [v0.0.5](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.4...v0.0.5) - 2023-04-25
- Use a token generated by GitHub Apps to launch recursive workflows by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/19
- Publish to pypi.org instead of testpypi.org by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/21
- Update dev dependencies by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/22
- Replace version numbers in project during release by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/23

## [v0.0.4](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.3...v0.0.4) - 2023-04-25
- Introduce Songmu/tagpr by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/17

## [v0.0.3](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.2...v0.0.3) - 2023-03-29
- Enable to configure s3 settings by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/11

## [v0.0.2](https://github.com/kai2nenobu/aws-clipper/compare/v0.0.1...v0.0.2) - 2023-03-28
- Fix profile name bug by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/9
- Add a release workflow by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/10

## [v0.0.1](https://github.com/kai2nenobu/aws-clipper/commits/v0.0.1) - 2023-03-26
- Add reviewdog workflows by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/1
- Introduce pre-commit by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/2
- Test in CI by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/3
- Rename application to aws-clipper by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/4
- Add a feature to group profiles by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/5
- Parse args and add an option to show a help message by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/6
- Calculate coverage in tests by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/7
- Determin package version based on git tags by @kai2nenobu in https://github.com/kai2nenobu/aws-clipper/pull/8
